@@ -9,6 +9,8 @@ from indico_install.kube.svc.restart import restart
 from indico_install.infra.single_node import single_node
 from indico_install.infra.gke import gke
 from indico_install.infra.aks import aks
+from indico_install.cluster_manager import ClusterManager
+
 
 # Here we try and include the EKS function
 # It depends on boto3 which may not be installed
@@ -22,6 +24,11 @@ except Exception:
         """Not available"""
         pass
 
+try:
+    default_namespace = ClusterManager().cluster_config["defaultNamespace"]
+except:
+    default_namespace = "default"
+
 @click.group("infra")
 @click.pass_context
 def infra(ctx):
@@ -33,7 +40,7 @@ def infra(ctx):
     pass
 
 
-def update_secret(secret_name, namespace="default"):
+def update_secret(secret_name, namespace=default_namespace):
     """
     Update an existing secret
     """
