@@ -58,6 +58,11 @@ def ask_for_infra_input(conf):
         type=str,
         default=conf.get("cluster", {}).get("name"),
     )
+    default_namespace = prompt(
+        "What is the name of your default indico namespace?",
+        type=str,
+        default=conf.get("cluster", {}).get("defaultNamespace"),
+    )
     gateway_name = prompt(
         "What is the name of your storage gateway?",
         type=str,
@@ -91,6 +96,7 @@ def ask_for_infra_input(conf):
             "annotations", {}
         ).pop(internal_elb_annotation, None)
 
+    conf["defaultNamespace"] = default_namespace
     conf["cluster"] = {"name": cluster_name, "gatewayName": gateway_name}
     return conf
 
